darkhistory.low\_energy.lowE\_photons.getf\_excitation
======================================================

.. currentmodule:: darkhistory.low_energy.lowE_photons

.. autofunction:: getf_excitation